To prevent hardcoding content and to enforce usage of appropriate i18n keys

##Installation
You'll first need to install **ESLint**:

```$ npm i eslint --save-dev```
Next, install `eslint-plugin-no-hardcoding`:

```$ npm install eslint-plugin-no-hardcoding --save-dev```
###Note: If you installed ESLint globally (using the -g flag) then you must also install `eslint-plugin-no-hardcoding` globally.

##Usage
Add `@zohodesk/no-hardcoding` to the plugins section of your `.eslintrc` configuration file.

```{```
  ```"plugins": ["@zohodesk/no-hardcoding"]```
```}```
Then configure the rules you want to use under the rules section.

```{```
  ```"rules": {```
    ```"@zohodesk/no-hardcoding/no-hardcoding": [errror,{props:[],objectKeys:[],methods:[],allowedTags:[]}],```
    ```"@zohodesk/no-hardcoding/use-getI18NValue-method-appropriately": [errror,{i18nKeys:[],comments:[]}]```
  ```}```
```}```
###Note: When configuring the severity of the no-hardcoding rule `@zohodesk/no-hardcoding/no-hardcoding` as a second argument in the array an object with the properties 'methods','props','objectKeys','allowedTags','keys','commentsToIgnoreHardcodingCheck','stringsAllowedAsBlockCommentStart','stringsAllowedAsBlockCommentEnd','dateFormatPatterns' must be mandatorily given. The value of these properties should be an array and entries into the array can be added if required

###Note: When configuring the severity of the no-hardcoding rule `@zohodesk/no-hardcoding/no-hardcoding` as a second argument in the array an object with the properties 'i18nKeys','commentsToIgnoreCheck' must be mandatorily given. The value of these properties should be an array and entries into the array can be added if required

##List of supported rules
@zohodesk/no-hardcoding/no-hardcoding,
@zohodesk/no-hardcoding/use-getI18NValue-method-appropriately

##Cases where the @zohodesk/no-hardcoding/no-hardcoding rule will report error:
1. ```<Container displayLabel='hardcoded string' /> ```

2. ```let obj = {```
        ```key: 'hardcoded string'```
    ```}```

3. ```let test = "test variable"```

4. ```let i18nText = getI18NValue('Incorrect key')```
    When an incorrect key is used inside the i18n method getI18NValue error will be reported

##Cases where the @zohodesk/no-hardcoding/no-hardcoding rule will not report error
1. ```<Container className="test string" dataId='any string' />```
    Hardcoding string in certain props like className, dataId etc are by default not reported as errors. Such props where error should not be thrown can be configured in the configuration object given in the configuration file while configuring the rule(as explained above on how to configure the rules)

2. ```let obj = { dataId: 'any string'}```
    Hardcoding string in certain object properties/keys like className, dataId,iconSize,boxSize etc are by default not reported as errors. Such object keys/properties where error should not be thrown can be configured in the configuration object given in the configuration file while configuring the rule(as explained above on how to configure the rules)

3. ```let index = findIndex('hardcoded string')```
    Hardcoding string in certain methods like findIndex,includes, addEventListener etc are by default not reported as errors. Such methods where error should not be thrown can be configured in the configuration object given in the configuration file while configuring the rule(as explained above on how to configure the rules)

4. ```<svg title='hardcoded string' d='test'> </svg>```
    Hardcoding strings in certain tags like svg are by default excluded from being reported as error. Such tags can be configured in the configuration object given in the configuration file while configuring the rule(as explained above on how to configure the rules)

5. ```let i18nedValue = getI18NValue('Product Information')``` 
    Here the string 'Product Information' is actually an i18n key and passed to appropriate method getI18NValue. Hence 
    it won't be reported as error. Such hardcoded strings which are correct i18n keys need to be configured in the configuration object given in the configuration file while configuring the rule(as explained above on how to configure the rules)

6. ```let seqOfNums = "0 0 12 20"```

7. ```let num = obj["spaced key"] ```
    Here the word "spaced key" is actully a property name in the object 'obj' and hence won't be reported as error

8. ```let dateFormat = 'DD MMM YYYY hh:mm A'```
    Date formats like above won't be reported as hardcoding errors. Such date format patterns can be configured in the configuration object given in the configuration file while configuring the rule(as explained above on how to configure the rules)

9. ```let cssProp = '10px #34rfe3' ```
    css properties won't be reported as hardcoding errors

10. ``` throw 'any string' ```
    strings given as argument to throw expressions won't be reported as hardcoding errors

11. ``` return new Error('any string') ```
    strings passed as arguments to "Error" won't be reported as hardcoding errors 

12. ```if(someVar === 'any string'){}```
    strings used for comparison in if conditions won't be reported as hardcoding errors 

13. ``` let someVar = "any string" === "another string" ? true : false```
    strings used for comparison in ternary operators won't be reported as hardcoding errors 

14. ```let someVar = 'hardcoded string' //no i18n```
    when the comment 'no i18n' is added hardcoding error will not be reported in the particular line

15. ``` let obj = { //ignore i18n start```
    ```title: 'hardcoded string',```
    ```displayLabel: 'Show tickets',```
    ```text: 'In Progress',```
    ```buttonText: 'Leave now'```
```} //ignore i18n end```
    if the block comment 'ignore i18n start' and 'ignore i18n end' is added no hardcoding error will be reported in the lines between the comment